# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
)


def lazy_import():
    from datadog_api_client.v1.model.note_widget_definition_type import NoteWidgetDefinitionType
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.widget_tick_edge import WidgetTickEdge
    from datadog_api_client.v1.model.widget_vertical_align import WidgetVerticalAlign

    globals()["NoteWidgetDefinitionType"] = NoteWidgetDefinitionType
    globals()["WidgetTextAlign"] = WidgetTextAlign
    globals()["WidgetTickEdge"] = WidgetTickEdge
    globals()["WidgetVerticalAlign"] = WidgetVerticalAlign


class NoteWidgetDefinition(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {}

    validations = {}

    additional_properties_type = None

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            "content": (str,),  # noqa: E501
            "type": (NoteWidgetDefinitionType,),  # noqa: E501
            "background_color": (str,),  # noqa: E501
            "font_size": (str,),  # noqa: E501
            "has_padding": (bool,),  # noqa: E501
            "show_tick": (bool,),  # noqa: E501
            "text_align": (WidgetTextAlign,),  # noqa: E501
            "tick_edge": (WidgetTickEdge,),  # noqa: E501
            "tick_pos": (str,),  # noqa: E501
            "vertical_align": (WidgetVerticalAlign,),  # noqa: E501
        }

    discriminator = None

    attribute_map = {
        "content": "content",  # noqa: E501
        "type": "type",  # noqa: E501
        "background_color": "background_color",  # noqa: E501
        "font_size": "font_size",  # noqa: E501
        "has_padding": "has_padding",  # noqa: E501
        "show_tick": "show_tick",  # noqa: E501
        "text_align": "text_align",  # noqa: E501
        "tick_edge": "tick_edge",  # noqa: E501
        "tick_pos": "tick_pos",  # noqa: E501
        "vertical_align": "vertical_align",  # noqa: E501
    }

    read_only_vars = {}

    _composed_schemas = {}

    @convert_js_args_to_python_args
    def __init__(self, content, type, *args, **kwargs):  # noqa: E501
        """NoteWidgetDefinition - a model defined in OpenAPI

        Args:
            content (str): Content of the note.
            type (NoteWidgetDefinitionType):

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            background_color (str): Background color of the note.. [optional]  # noqa: E501
            font_size (str): Size of the text.. [optional]  # noqa: E501
            has_padding (bool): Whether to add padding or not.. [optional] if omitted the server will use the default value of True  # noqa: E501
            show_tick (bool): Whether to show a tick or not.. [optional]  # noqa: E501
            text_align (WidgetTextAlign): [optional]  # noqa: E501
            tick_edge (WidgetTickEdge): [optional]  # noqa: E501
            tick_pos (str): Where to position the tick on an edge.. [optional]  # noqa: E501
            vertical_align (WidgetVerticalAlign): [optional]  # noqa: E501
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.content = content
        self.type = type

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, content, type, *args, **kwargs):  # noqa: E501
        """Helper creating a new instance from a response."""

        self = super(NoteWidgetDefinition, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.content = content
        self.type = type
        return self
