# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
)


def lazy_import():
    from datadog_api_client.v1.model.slo_error_budget_remaining_data import SLOErrorBudgetRemainingData
    from datadog_api_client.v1.model.slo_history_response_error_with_type import SLOHistoryResponseErrorWithType

    globals()["SLOErrorBudgetRemainingData"] = SLOErrorBudgetRemainingData
    globals()["SLOHistoryResponseErrorWithType"] = SLOHistoryResponseErrorWithType


class SLOHistoryMonitor(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {}

    validations = {}

    additional_properties_type = None

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            "error_budget_remaining": (SLOErrorBudgetRemainingData,),  # noqa: E501
            "errors": ([SLOHistoryResponseErrorWithType],),  # noqa: E501
            "group": (str,),  # noqa: E501
            "history": ([[float]],),  # noqa: E501
            "monitor_modified": (int,),  # noqa: E501
            "monitor_type": (str,),  # noqa: E501
            "name": (str,),  # noqa: E501
            "precision": (float,),  # noqa: E501
            "preview": (bool,),  # noqa: E501
            "sli_value": (float,),  # noqa: E501
            "span_precision": (float,),  # noqa: E501
            "uptime": (float,),  # noqa: E501
        }

    discriminator = None

    attribute_map = {
        "error_budget_remaining": "error_budget_remaining",  # noqa: E501
        "errors": "errors",  # noqa: E501
        "group": "group",  # noqa: E501
        "history": "history",  # noqa: E501
        "monitor_modified": "monitor_modified",  # noqa: E501
        "monitor_type": "monitor_type",  # noqa: E501
        "name": "name",  # noqa: E501
        "precision": "precision",  # noqa: E501
        "preview": "preview",  # noqa: E501
        "sli_value": "sli_value",  # noqa: E501
        "span_precision": "span_precision",  # noqa: E501
        "uptime": "uptime",  # noqa: E501
    }

    read_only_vars = {}

    _composed_schemas = {}

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """SLOHistoryMonitor - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            error_budget_remaining (SLOErrorBudgetRemainingData): [optional]  # noqa: E501
            errors ([SLOHistoryResponseErrorWithType]): An array of error objects returned while querying the history data for the service level objective.. [optional]  # noqa: E501
            group (str): For groups in a grouped SLO, this is the group name.. [optional]  # noqa: E501
            history ([[float]]): For `monitor` based SLOs, this includes the aggregated history as arrays that include time series and uptime data where `0=monitor` is in `OK` state and `1=monitor` is in `alert` state.. [optional]  # noqa: E501
            monitor_modified (int): For `monitor` based SLOs, this is the last modified timestamp in epoch seconds of the monitor.. [optional]  # noqa: E501
            monitor_type (str): For `monitor` based SLOs, this describes the type of monitor.. [optional]  # noqa: E501
            name (str): For groups in a grouped SLO, this is the group name. For monitors in a multi-monitor SLO, this is the monitor name.. [optional]  # noqa: E501
            precision (float): The amount of decimal places the SLI value is accurate to for the given from `&&` to timestamp. Use `span_precision` instead.. [optional]  # noqa: E501
            preview (bool): For `monitor` based SLOs, when `true` this indicates that a replay is in progress to give an accurate uptime calculation.. [optional]  # noqa: E501
            sli_value (float): The current SLI value of the SLO over the history window.. [optional]  # noqa: E501
            span_precision (float): The amount of decimal places the SLI value is accurate to for the given from `&&` to timestamp.. [optional]  # noqa: E501
            uptime (float): Use `sli_value` instead.. [optional]  # noqa: E501
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """Helper creating a new instance from a response."""

        self = super(SLOHistoryMonitor, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
